==> haskell-blaze-textual-0.2.3.1-130.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-FoY2EPiiF1nGiO9F7KrpNI
key:                  blaze-textual-0.2.3.1-FoY2EPiiF1nGiO9F7KrpNI
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  36ea40e238e3a394157769e71ba1862a
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-FoY2EPiiF1nGiO9F7KrpNI
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    bytestring-0.11.5.3 ghc-prim-0.10.0 integer-gmp-1.1
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC text-2.0.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-textual-0.2.3.1-131-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-5Xux47dVybF283KdRf2DU7
key:                  blaze-textual-0.2.3.1-5Xux47dVybF283KdRf2DU7
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  8b4ba89c693f5d310be71d69b2c22969
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-5Xux47dVybF283KdRf2DU7
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    bytestring-0.11.5.3 ghc-prim-0.10.0 integer-gmp-1.1
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC text-2.0.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
